@@ -1,17 +1,94 @@
 package Form::Factory;
-$Form::Factory::VERSION = '0.021';
+$Form::Factory::VERSION = '0.022';
 use Moose;
 
 use Carp ();
 use Class::Load;
 
+# ABSTRACT: a general-purpose form handling API
+
+
+sub new_interface {
+    my $class = shift;
+    my $name  = shift;
+    my $class_name = $class->interface_class($name);
+    return $class_name->new(@_);
+}
+
+
+sub interface_class { _load_class_from_name(Interface => $_[1]) }
+
+
+sub control_class { _load_class_from_name(Control => $_[1]) }
+
+
+sub feature_class { _load_class_from_name(Feature => $_[1]) }
+
+
+sub control_feature_class { _load_class_from_name('Feature::Control' => $_[1]) }
+
+
+sub _class_name_from_name {
+    my ($prefix, $name) = @_;
+
+    # Remove anything like #Foo, which is used to differentiate between features
+    # added by different classes in get_all_features()
+    $name =~ s/\#(.*)$//;
+
+    # Turn a foo_bar_baz name into FooBarBaz
+    $name =~ s/(?:[^A-Za-z]+|^)([A-Za-z])/\U$1/g;
+
+    return join('::', 'Form::Factory', $prefix, ucfirst $name);
+}
+
+sub _load_class_from_name {
+    my ($given_type, $name) = @_;
+    my $ERROR;
+
+    my $custom_type = join('::', $given_type, 'Custom');
+    for my $type ($given_type, $custom_type) {
+        my $class_name = _class_name_from_name($type, $name);
+
+        if (not eval { Class::Load::load_class($class_name) }) {
+            $ERROR ||= $@ if $@;
+            $ERROR ||= "failed to load $type class named $name";;
+        }
+        elsif ($type eq $custom_type) {
+            $class_name = $class_name->register_implementation;
+
+            if (eval { Class::Load::load_class($class_name) }) {
+                return $class_name;
+            }
+            else {
+                undef $ERROR;
+                $ERROR ||= $@ if $@;
+                $ERROR ||= "failed to load $type class named $name";;
+            }
+        }
+        else {
+            return $class_name;
+        }
+    }
+
+    Carp::croak($ERROR);
+}
+
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory - a general-purpose form handling API
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -88,15 +165,6 @@ This creates a L<Form::Factory::Interface> object with the given options. This i
   my $interface_class = Form::Factory->interface_class($name);
   my $interface       = $interface_class->new(\%options);
 
-=cut
-
-sub new_interface {
-    my $class = shift;
-    my $name  = shift;
-    my $class_name = $class->interface_class($name);
-    return $class_name->new(@_);
-}
-
 =head2 interface_class
 
   my $class_name = Form::Factory->interface_class('HTML');
@@ -105,10 +173,6 @@ Returns the interface class for the named interface. This loads the interface cl
 
 See L</CLASS LOADING>.
 
-=cut
-
-sub interface_class { _load_class_from_name(Interface => $_[1]) }
-
 =head2 control_class
 
   my $class_name = Form::Factory->control_class('full_text');
@@ -117,10 +181,6 @@ Returns the control class for the named control. This loads the control class fr
 
 See L</CLASS LOADING>.
 
-=cut
-
-sub control_class { _load_class_from_name(Control => $_[1]) }
-
 =head2 feature_class
 
   my $class_name = Form::Factory->feature_class('functional');
@@ -129,10 +189,6 @@ Returns the feature class for the named feature. This loads the feature class fr
 
 See L</CLASS LOADING>.
 
-=cut
-
-sub feature_class { _load_class_from_name(Feature => $_[1]) }
-
 =head2 control_feature_class
 
   my $class_name = Form::Factory->control_feature_class('required');
@@ -141,10 +197,6 @@ Returns the control feature class for the named control feature. This loads the
 
 See L</CLASS LOADING>.
 
-=cut
-
-sub control_feature_class { _load_class_from_name('Feature::Control' => $_[1]) }
-
 =head1 CLASS LOADING
 
 This package features a few class loading methods. These methods each load a type of class. The type of class depends on the namespace they are based upon (which is mentioned in the documentation for each class loading method).
@@ -175,53 +227,6 @@ Though, you probably actually want:
 
   my $interface = Form::Factory->new_interface('MyAppHTML');
 
-=cut
-
-sub _class_name_from_name {
-    my ($prefix, $name) = @_;
-
-    # Remove anything like #Foo, which is used to differentiate between features
-    # added by different classes in get_all_features()
-    $name =~ s/\#(.*)$//;
-
-    # Turn a foo_bar_baz name into FooBarBaz
-    $name =~ s/(?:[^A-Za-z]+|^)([A-Za-z])/\U$1/g;
-
-    return join('::', 'Form::Factory', $prefix, ucfirst $name);
-}
-
-sub _load_class_from_name {
-    my ($given_type, $name) = @_;
-    my $ERROR;
-
-    my $custom_type = join('::', $given_type, 'Custom');
-    for my $type ($given_type, $custom_type) {
-        my $class_name = _class_name_from_name($type, $name);
-
-        if (not eval { Class::Load::load_class($class_name) }) {
-            $ERROR ||= $@ if $@;
-            $ERROR ||= "failed to load $type class named $name";;
-        }
-        elsif ($type eq $custom_type) {
-            $class_name = $class_name->register_implementation;
-
-            if (eval { Class::Load::load_class($class_name) }) {
-                return $class_name;
-            }
-            else {
-                undef $ERROR;
-                $ERROR ||= $@ if $@;
-                $ERROR ||= "failed to load $type class named $name";;
-            }
-        }
-        else {
-            return $class_name;
-        }
-    }
-
-    Carp::croak($ERROR);
-}
-
 =head1 TODO
 
 This is not definite, but some things I know as of right now I'm not happy with:
@@ -258,15 +263,13 @@ L<Form::Factory::Interface::CLI>, L<Form::Factory::Interface::HTML>
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
