@@ -1,5 +1,5 @@
 package Form::Factory::Action;
-$Form::Factory::Action::VERSION = '0.021';
+$Form::Factory::Action::VERSION = '0.022';
 use Moose::Role;
 
 use Carp ();
@@ -9,42 +9,8 @@ use Form::Factory::Result::Single;
 
 #requires qw( run );
 
-=head1 NAME
+# ABSTRACT: Role implemented by actions
 
-Form::Factory::Action - Role implemented by actions
-
-=head1 VERSION
-
-version 0.021
-
-=head2 SYNOPSIS
-
-  package MyApp::Action::Foo;
-  use Form::Factory::Processor;
-
-  has_control bar => (
-      type => 'text',
-  );
-
-  sub run {
-      my $self = shift;
-
-      # Do something...
-  }
-
-=head1 DESCRIPTION
-
-This is the role implemented by all form actions. Rather than doing so directly, you should use L<Form::Factory::Processor> as demonstrated in the L</SYNOPSIS>.
-
-=head1 ATTRIBUTES
-
-All form actions have the following attributes.
-
-=head2 form_interface
-
-This is the L<Form::Factory::Interface> that constructed this action. If you need to get at the implementation directly for some reason, here it is. This is mostly used by the action itself when calling the L</render> and L</consume> methods.
-
-=cut
 
 has form_interface => (
     is        => 'ro',
@@ -52,11 +18,6 @@ has form_interface => (
     required  => 1,
 );
 
-=head2 globals
-
-This is a hash of extra parameters to keep with the form. Normally, these are saved with a call to L</stash> and recovered with a call to L</unstash>.
-
-=cut
 
 has globals => (
     is        => 'ro',
@@ -65,13 +26,6 @@ has globals => (
     default   => sub { {} },
 );
 
-=head2 results
-
-This is a L<Form::Factory::Result::Gathered> object that tracks the general success, failure, messages, and output from the execution of this action.
-
-Actions delegate a number of methods to this object. See L</RESULTS>.
-
-=cut
 
 has results => (
     is        => 'rw',
@@ -92,13 +46,6 @@ has results => (
     ) ],
 );
 
-=head2 result
-
-This is a L<Form::Factory::Result::Single> used to record general outcome.
-
-Actions delegate a number of methods to this object. See L</RESULTS>.
-
-=cut
 
 has result => (
     is        => 'rw',
@@ -115,11 +62,6 @@ has result => (
     ) ],
 );
 
-=head2 features
-
-This is a list of L<Form::Factory::Feature> objects used to modify the object. This will always contain the features that are attached to the class itself. Additional features may be added here.
-
-=cut
 
 has features => (
     is          => 'ro',
@@ -155,11 +97,6 @@ sub _init_features {
     $set->($features);
 }
 
-=head2 controls
-
-This is a hash of controls attached to this action. For every C<has_control> line in the action class, there should be a matching control in this hash.
-
-=cut
 
 has controls => (
     is        => 'ro',
@@ -250,17 +187,6 @@ sub _build_controls {
     return \%controls;
 }
 
-=head1 METHODS
-
-=head2 stash
-
-  $action->stash($moniker);
-
-Given a C<$moniker> (a key under which to store the information related to this form), this will stash the form's stashable information under that name using the L<Form::Factory::Stasher> associated with the L</form_interface>.
-
-The globals, values of controls, and the results are stashed. This allows those values to be recovered across requests or between process calls or whatever the implementation requires.
-
-=cut
 
 sub stash {
     my ($self, $moniker) = @_;
@@ -282,13 +208,6 @@ sub stash {
     $self->form_interface->stash($moniker => \%stash);
 }
 
-=head2 unstash
-
-  $action->unstash($moniker);
-
-Given a C<$moniker> previously named in a call to L</stash>, it restores the previously stashed state. This is a no-op if nothing is stashed under this moniker.
-
-=cut
 
 sub unstash {
     my ($self, $moniker) = @_;
@@ -313,11 +232,6 @@ sub unstash {
     $self->result($stash->{result} || Form::Factory::Result::Single->new);
 }
 
-=head2 clear
-
-This method clears the stashable state of the action.
-
-=cut
 
 sub clear {
     my ($self) = @_;
@@ -334,23 +248,6 @@ sub clear {
     $self->result(Form::Factory::Result::Single->new);
 }
 
-=head2 render
-
-  $action->render(%options);
-
-Renders the form using the associated L</form_interface>. You may specify the following options:
-
-=over
-
-=item controls
-
-This is a list of control names to render. If not given, all controls will be rendered.
-
-=back
-
-Any other options will be passed on to the L<Form::Factory::Interface/render_control> method.
-
-=cut
 
 sub render {
     my $self = shift;
@@ -367,37 +264,6 @@ sub render {
     return;
 }
 
-=head2 setup_and_render
-
-  $self->setup_and_render(%options);
-
-This performs the most common steps to prepare for a render and render:
-
-=over
-
-=item 1
-
-Unstashes from the given C<moniker>.
-
-=item 2
-
-Adds the given C<globals> to the globals.
-
-=item 3
-
-Renders the action.
-
-=item 4
-
-Clears the results.
-
-=item 5
-
-Stashes what we've done back into the given C<moniker>.
-
-=back
-
-=cut
 
 sub setup_and_render {
     my ($self, %options) = @_;
@@ -414,15 +280,6 @@ sub setup_and_render {
     return;
 }
 
-=head2 render_control
-
-  my $control = $action->render_control($name, \%options);
-
-Creates and renders a one time control. This is mostly useful for attaching buttons to a form. The control is not added to the list of controls on the action and will not be processed later.
-
-This method returns the control object that was just rendered.
-
-=cut
 
 sub render_control {
     my ($self, $name, $options, %params) = @_;
@@ -440,23 +297,6 @@ sub render_control {
     return $control;
 }
 
-=head2 consume
-
-  $action->consume(%options);
-
-This consumes any input from user and places it into the controls of the form. You may pass the following options:
-
-=over
-
-=item controls
-
-This is a list of names of controls to consume. Any not listed here will not be consumed. If this option is missing, all control values are consumed.
-
-=back
-
-Any additional options will be passed to the L<Form::Factory::Interface/consume_control> method call.
-
-=cut
 
 sub consume {
     my $self   = shift;
@@ -470,15 +310,6 @@ sub consume {
     $self->form_interface->consume_control($controls->{$_}, %params) for @names;
 }
 
-=head2 consume_control
-
-  my $control = $action->consume_control($name, \%options, %params);
-
-Consumes the value of a one time control. This is useful for testing to see if a form submitted using a one-time control has been submitted or not.
-
-This method returns the control object that was consumed.
-
-=cut
 
 sub consume_control {
     my ($self, $name, $options, %params) = @_;
@@ -496,25 +327,6 @@ sub consume_control {
     return $control;
 }
 
-=head2 clean
-
-  $action->clean(%options);
-
-Takes the values consumed from the user and cleans them up. For example, if you allow users to type in a phone number, this can be used to clear out any unwanted or incorrect punctuation and format the phone number properly.
-
-This method runs through all the requested L<Form::Factory::Feature> objects in L</features> and runs the L<Form::Factory::Feature/clean> method for each.
-
-The following options are used:
-
-=over
-
-=item controls
-
-This is the list of controls to clean. If not given, all features will be run. If given, only the control-features (those implementing L<Form::Factory::Feature::Role::Control> attached to the named controls) will be run. Any form-features or unlisted control-features will not be run.
-
-=back
-
-=cut
 
 {
     sub _run_features {
@@ -556,6 +368,258 @@ sub clean {
     $self->_run_features(clean => @_);
 }
 
+
+sub check {
+    my $self = shift;
+    $self->_run_features(check => @_);
+
+    $self->gather_results;
+}
+
+
+sub process {
+    my $self = shift;
+    return unless $self->is_valid;
+
+    $self->set_attributes_from_controls;
+
+    $self->_run_features('pre_process');
+    $self->run;
+    $self->_run_features('post_process');
+
+    $self->gather_results;
+
+    my @errors = $self->error_messages;
+    $self->result->is_success(@errors == 0);
+}
+
+
+sub consume_and_clean_and_check_and_process {
+    my $self = shift;
+    $self->consume(@_);
+    $self->clean;
+    $self->check;
+    $self->process;
+}
+
+
+sub set_attribute_from_control {
+    my ($self, $name) = @_;
+    my $meta = $self->meta;
+
+    my $control   = $self->control->{$name};
+    my $attribute = $meta->find_attribute_by_name($name);
+    $control->set_attribute_value($self, $attribute);
+}
+
+
+sub set_attributes_from_controls {
+    my $self = shift;
+    my $meta = $self->meta;
+
+    my $controls = $self->controls;
+    while (my ($name, $control) = each %$controls) {
+        my $attribute = $meta->find_attribute_by_name($name);
+        Carp::croak("attribute for control $name not found on $self")
+            unless defined $attribute;
+        $control->set_attribute_value($self, $attribute);
+    }
+}
+
+
+sub gather_results {
+    my $self = shift;
+    my $controls = $self->controls;
+    $self->results->gather_results( 
+        $self->result, 
+        map { $_->result } @{ $self->features } 
+    );
+}
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Form::Factory::Action - Role implemented by actions
+
+=head1 VERSION
+
+version 0.022
+
+=head1 DESCRIPTION
+
+This is the role implemented by all form actions. Rather than doing so directly, you should use L<Form::Factory::Processor> as demonstrated in the L</SYNOPSIS>.
+
+=head2 SYNOPSIS
+
+  package MyApp::Action::Foo;
+  use Form::Factory::Processor;
+
+  has_control bar => (
+      type => 'text',
+  );
+
+  sub run {
+      my $self = shift;
+
+      # Do something...
+  }
+
+=head1 ATTRIBUTES
+
+All form actions have the following attributes.
+
+=head2 form_interface
+
+This is the L<Form::Factory::Interface> that constructed this action. If you need to get at the implementation directly for some reason, here it is. This is mostly used by the action itself when calling the L</render> and L</consume> methods.
+
+=head2 globals
+
+This is a hash of extra parameters to keep with the form. Normally, these are saved with a call to L</stash> and recovered with a call to L</unstash>.
+
+=head2 results
+
+This is a L<Form::Factory::Result::Gathered> object that tracks the general success, failure, messages, and output from the execution of this action.
+
+Actions delegate a number of methods to this object. See L</RESULTS>.
+
+=head2 result
+
+This is a L<Form::Factory::Result::Single> used to record general outcome.
+
+Actions delegate a number of methods to this object. See L</RESULTS>.
+
+=head2 features
+
+This is a list of L<Form::Factory::Feature> objects used to modify the object. This will always contain the features that are attached to the class itself. Additional features may be added here.
+
+=head2 controls
+
+This is a hash of controls attached to this action. For every C<has_control> line in the action class, there should be a matching control in this hash.
+
+=head1 METHODS
+
+=head2 stash
+
+  $action->stash($moniker);
+
+Given a C<$moniker> (a key under which to store the information related to this form), this will stash the form's stashable information under that name using the L<Form::Factory::Stasher> associated with the L</form_interface>.
+
+The globals, values of controls, and the results are stashed. This allows those values to be recovered across requests or between process calls or whatever the implementation requires.
+
+=head2 unstash
+
+  $action->unstash($moniker);
+
+Given a C<$moniker> previously named in a call to L</stash>, it restores the previously stashed state. This is a no-op if nothing is stashed under this moniker.
+
+=head2 clear
+
+This method clears the stashable state of the action.
+
+=head2 render
+
+  $action->render(%options);
+
+Renders the form using the associated L</form_interface>. You may specify the following options:
+
+=over
+
+=item controls
+
+This is a list of control names to render. If not given, all controls will be rendered.
+
+=back
+
+Any other options will be passed on to the L<Form::Factory::Interface/render_control> method.
+
+=head2 setup_and_render
+
+  $self->setup_and_render(%options);
+
+This performs the most common steps to prepare for a render and render:
+
+=over
+
+=item 1
+
+Unstashes from the given C<moniker>.
+
+=item 2
+
+Adds the given C<globals> to the globals.
+
+=item 3
+
+Renders the action.
+
+=item 4
+
+Clears the results.
+
+=item 5
+
+Stashes what we've done back into the given C<moniker>.
+
+=back
+
+=head2 render_control
+
+  my $control = $action->render_control($name, \%options);
+
+Creates and renders a one time control. This is mostly useful for attaching buttons to a form. The control is not added to the list of controls on the action and will not be processed later.
+
+This method returns the control object that was just rendered.
+
+=head2 consume
+
+  $action->consume(%options);
+
+This consumes any input from user and places it into the controls of the form. You may pass the following options:
+
+=over
+
+=item controls
+
+This is a list of names of controls to consume. Any not listed here will not be consumed. If this option is missing, all control values are consumed.
+
+=back
+
+Any additional options will be passed to the L<Form::Factory::Interface/consume_control> method call.
+
+=head2 consume_control
+
+  my $control = $action->consume_control($name, \%options, %params);
+
+Consumes the value of a one time control. This is useful for testing to see if a form submitted using a one-time control has been submitted or not.
+
+This method returns the control object that was consumed.
+
+=head2 clean
+
+  $action->clean(%options);
+
+Takes the values consumed from the user and cleans them up. For example, if you allow users to type in a phone number, this can be used to clear out any unwanted or incorrect punctuation and format the phone number properly.
+
+This method runs through all the requested L<Form::Factory::Feature> objects in L</features> and runs the L<Form::Factory::Feature/clean> method for each.
+
+The following options are used:
+
+=over
+
+=item controls
+
+This is the list of controls to clean. If not given, all features will be run. If given, only the control-features (those implementing L<Form::Factory::Feature::Role::Control> attached to the named controls) will be run. Any form-features or unlisted control-features will not be run.
+
+=back
+
 =head2 check
 
   $action->check(%options);
@@ -574,15 +638,6 @@ This is the list of controls to check. If not given, all features will be run. I
 
 =back
 
-=cut
-
-sub check {
-    my $self = shift;
-    $self->_run_features(check => @_);
-
-    $self->gather_results;
-}
-
 =head2 process
 
   $action->process;
@@ -591,24 +646,6 @@ This does nothing if the action did not validate.
 
 In the case the action is valid, this will use L</set_attributes_from_controls> to copy the control values to the action attributes, run the L<Form::Factory::Feature/pre_process> methods for all form-features and control-features, call the L</run> method, run the L<Form::Factory::Feature/post_process> methods for all form-features and control-features, and set the C<is_success> flag to true if no errors are recorded or false if there are.
 
-=cut
-
-sub process {
-    my $self = shift;
-    return unless $self->is_valid;
-
-    $self->set_attributes_from_controls;
-
-    $self->_run_features('pre_process');
-    $self->run;
-    $self->_run_features('post_process');
-
-    $self->gather_results;
-
-    my @errors = $self->error_messages;
-    $self->result->is_success(@errors == 0);
-}
-
 =head2 consume_and_clean_and_check_and_process
 
 This is a shortcut for taking all the usual workflow actions in a single call:
@@ -618,16 +655,6 @@ This is a shortcut for taking all the usual workflow actions in a single call:
   $action->check
   $action->process;
 
-=cut
-
-sub consume_and_clean_and_check_and_process {
-    my $self = shift;
-    $self->consume(@_);
-    $self->clean;
-    $self->check;
-    $self->process;
-}
-
 =head1 ROLE METHODS
 
 This method must be implemented by any action implementation.
@@ -644,51 +671,14 @@ These methods are primarily intended for internal use.
 
 Given the name of a control, this will copy the current value in the control to the attribute.
 
-=cut
-
-sub set_attribute_from_control {
-    my ($self, $name) = @_;
-    my $meta = $self->meta;
-
-    my $control   = $self->control->{$name};
-    my $attribute = $meta->find_attribute_by_name($name);
-    $control->set_attribute_value($self, $attribute);
-}
-
 =head2 set_attributes_from_controls
 
 This method is used by L</process> to copy the values out of the controls into the form action attributes. This assumes that such a copy will work because the L</clean> and L</check> phases should have already run and passed without error.
 
-=cut
-
-sub set_attributes_from_controls {
-    my $self = shift;
-    my $meta = $self->meta;
-
-    my $controls = $self->controls;
-    while (my ($name, $control) = each %$controls) {
-        my $attribute = $meta->find_attribute_by_name($name);
-        Carp::croak("attribute for control $name not found on $self")
-            unless defined $attribute;
-        $control->set_attribute_value($self, $attribute);
-    }
-}
-
 =head2 gather_results
 
 Gathers results for all the associated L</controls> and L</result> into L</results>. This is called just before deciding if the action has validated correctly or if the action has succeeded.
 
-=cut
-
-sub gather_results {
-    my $self = shift;
-    my $controls = $self->controls;
-    $self->results->gather_results( 
-        $self->result, 
-        map { $_->result } @{ $self->features } 
-    );
-}
-
 =head1 RESULTS
 
 Actions are tied closely to L<Form::Factory::Result>s. As such, a number of methods are delegated to result classes.
@@ -744,13 +734,13 @@ These methods are delegated to L<result> in L<Form::Factory::Result::Single>.
 =item failure
 
 =item add_message
-        
+
 =item info 
 
 =item warning 
 
 =item error
-        
+
 =item field_info 
 
 =item field_warning 
@@ -827,15 +817,13 @@ You will still run the steps above, but can do a check and clean on a subset of
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
