@@ -1,31 +1,9 @@
 package Form::Factory::Action::Meta::Class;
-$Form::Factory::Action::Meta::Class::VERSION = '0.021';
+$Form::Factory::Action::Meta::Class::VERSION = '0.022';
 use Moose::Role;
 
-=head1 NAME
+# ABSTRACT: The meta-class role for form actions
 
-Form::Factory::Action::Meta::Class - The meta-class role for form actions
-
-=head1 VERSION
-
-version 0.021
-
-=head1 SYNOPSIS
-
-  package MyApp::Action::Foo;
-  use Form::Factory::Processor;
-
-=head1 DESCRIPTION
-
-All form actions have this role attached to its meta-class.
-
-=head1 ATTRIBUTES
-
-=head2 features
-
-This is a hash of features. The keys are the short name of the feature to attach and the value is a hash of options to pass to the feature's constructor on instantiation.
-
-=cut
 
 has features => (
     is       => 'ro',
@@ -34,17 +12,6 @@ has features => (
     default  => sub { {} },
 );
 
-=head1 METHODS
-
-=head2 get_controls
-
-  my @attributes = $action->meta->get_controls(@names);
-
-Returns all the controls for this action. This includes controls inherited from parent classes as well. This returns a list of attributes which do L<Form::Factory::Action::Meta::Attribute::Control>.
-
-You may pass a list of control names if you only want a subset of the available controls. If no list is given, all controls are returned.
-
-=cut
 
 sub get_controls {
     my ($meta, @control_names) = @_;
@@ -65,13 +32,6 @@ sub get_controls {
                        @controls;
 }
 
-=head2 get_all_features
-
-  my $features = $action->meta->get_all_features;
-
-Returns all the feature specs for the form. This includes all inherited features and features configured in implemented roles as well. These are returned in the same format as the L</features> attribute.
-
-=cut
 
 sub get_all_features {
     my $meta = shift;
@@ -109,21 +69,67 @@ sub get_all_features {
     return \%all_features;
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Form::Factory::Action::Meta::Class - The meta-class role for form actions
+
+=head1 VERSION
+
+version 0.022
+
+=head1 SYNOPSIS
+
+  package MyApp::Action::Foo;
+  use Form::Factory::Processor;
+
+=head1 DESCRIPTION
+
+All form actions have this role attached to its meta-class.
+
+=head1 ATTRIBUTES
+
+=head2 features
+
+This is a hash of features. The keys are the short name of the feature to attach and the value is a hash of options to pass to the feature's constructor on instantiation.
+
+=head1 METHODS
+
+=head2 get_controls
+
+  my @attributes = $action->meta->get_controls(@names);
+
+Returns all the controls for this action. This includes controls inherited from parent classes as well. This returns a list of attributes which do L<Form::Factory::Action::Meta::Attribute::Control>.
+
+You may pass a list of control names if you only want a subset of the available controls. If no list is given, all controls are returned.
+
+=head2 get_all_features
+
+  my $features = $action->meta->get_all_features;
+
+Returns all the feature specs for the form. This includes all inherited features and features configured in implemented roles as well. These are returned in the same format as the L</features> attribute.
+
 =head1 SEE ALSO
 
 L<Form::Factory::Action>, L<Form::Factory::Control>, L<Form::Factory::Feature>, L<Form::Factory::Processor>
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
