@@ -1,16 +1,27 @@
 package Form::Factory::Action::Role;
-$Form::Factory::Action::Role::VERSION = '0.021';
+$Form::Factory::Action::Role::VERSION = '0.022';
 use Moose::Role;
 
 use Carp ();
 
+# ABSTRACT: Role implemented by action roles
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Action::Role - Role implemented by action roles
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -27,15 +38,13 @@ This is the role implemented by all form action roles. Do not use this directly,
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2010 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
