@@ -1,5 +1,5 @@
 package Form::Factory::Control::Checkbox;
-$Form::Factory::Control::Checkbox::VERSION = '0.021';
+$Form::Factory::Control::Checkbox::VERSION = '0.022';
 use Moose;
 
 with qw(
@@ -8,13 +8,37 @@ with qw(
     Form::Factory::Control::Role::Labeled
 );
 
+# ABSTRACT: the checkbox control
+
+
+has '+value' => (
+    isa       => 'Str',
+);
+
+has '+default_value' => (
+    isa       => 'Str',
+    lazy      => 1,
+    default   => sub { shift->false_value },
+);
+
+
+use constant default_isa => 'Str';
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Control::Checkbox - the checkbox control
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -31,39 +55,21 @@ version 0.021
 
 This represents a toggle button, typically displayed as a checkbox. This control implements L<Form::Factory::Control>, L<Form::Factory::Control::Role::BooleanValue>, L<Form::Factory::Control::Role::Labeled>, L<Form::Factory::Control::Role::ScalarValue>.
 
-=cut
-
-has '+value' => (
-    isa       => 'Str',
-);
-
-has '+default_value' => (
-    isa       => 'Str',
-    lazy      => 1,
-    default   => sub { shift->false_value },
-);
-
 =head1 METHODS
 
 =head2 default_isa
 
 Boolean values default to C<Bool>.
 
-=cut
-
-use constant default_isa => 'Str';
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
