@@ -1,14 +1,60 @@
 package Form::Factory::Control::Choice;
-$Form::Factory::Control::Choice::VERSION = '0.021';
+$Form::Factory::Control::Choice::VERSION = '0.022';
 use Moose;
 
+# ABSTRACT: Helper class for tracking choices
+
+
+has label => (
+    is        => 'ro',
+    isa       => 'Str',
+);
+
+
+has value => (
+    is        => 'ro',
+    isa       => 'Str',
+    required  => 1,
+);
+
+sub BUILDARGS {
+    my $class = shift;
+    my %args;
+
+    if (@_ == 1 and ref $_[0]) {
+        %args = %{ $_[0] };
+    }
+    elsif (@_ == 1) {
+        $args{value} = $_[0];
+    }
+    elsif (@_ == 2) {
+        $args{value} = $_[0];
+        $args{label} = $_[1];
+    }
+    else {
+        %args = @_;
+    }
+
+    $args{label} = $args{value} unless defined $args{label};
+
+    return $class->SUPER::BUILDARGS(%args);
+}
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Control::Choice - Helper class for tracking choices
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -46,59 +92,19 @@ If C<$value> and C<$label> are the same, all of those calls are identical.
 
 The label to give the choice.
 
-=cut
-
-has label => (
-    is        => 'ro',
-    isa       => 'Str',
-);
-
 =head2 value
 
 The value of the choice.
 
-=cut
-
-has value => (
-    is        => 'ro',
-    isa       => 'Str',
-    required  => 1,
-);
-
-sub BUILDARGS {
-    my $class = shift;
-    my %args;
-
-    if (@_ == 1 and ref $_[0]) {
-        %args = %{ $_[0] };
-    }
-    elsif (@_ == 1) {
-        $args{value} = $_[0];
-    }
-    elsif (@_ == 2) {
-        $args{value} = $_[0];
-        $args{label} = $_[1];
-    }
-    else {
-        %args = @_;
-    }
-
-    $args{label} = $args{value} unless defined $args{label};
-
-    return $class->SUPER::BUILDARGS(%args);
-}
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
