@@ -1,16 +1,33 @@
 package Form::Factory::Control::Role::AvailableChoices;
-$Form::Factory::Control::Role::AvailableChoices::VERSION = '0.021';
+$Form::Factory::Control::Role::AvailableChoices::VERSION = '0.022';
 use Moose::Role;
 
 use Form::Factory::Control::Choice;
 
+# ABSTRACT: Controls that list available choices
+
+
+has available_choices => (
+    is        => 'ro',
+    isa       => 'ArrayRef[Form::Factory::Control::Choice]',
+    required  => 1,
+);
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Control::Role::AvailableChoices - Controls that list available choices
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 DESCRIPTION
 
@@ -22,25 +39,15 @@ Controls that have a list of possible options to select from may implement this
 
 The list of L<Form::Factory::Control::Choice> objects.
 
-=cut
-
-has available_choices => (
-    is        => 'ro',
-    isa       => 'ArrayRef[Form::Factory::Control::Choice]',
-    required  => 1,
-);
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
