@@ -1,5 +1,5 @@
 package Form::Factory::Control::Role::BooleanValue;
-$Form::Factory::Control::Role::BooleanValue::VERSION = '0.021';
+$Form::Factory::Control::Role::BooleanValue::VERSION = '0.022';
 use Moose::Role;
 
 excludes qw(
@@ -7,25 +7,8 @@ excludes qw(
     Form::Factory::Control::Role::ScalarValue
 );
 
-=head1 NAME
+# ABSTRACT: boolean valued controls
 
-Form::Factory::Control::Role::BooleanValue - boolean valued controls
-
-=head1 VERSION
-
-version 0.021
-
-=head1 DESCRIPTION
-
-Controls that implement this role have a boolean value. This say much about how that is actually implemented, just that is has a L</true_value> a L</false_value> and then a flag stating whether the true value or false value is currently selected.
-
-=head1 ATTRIBUTES
-
-=head2 true_value
-
-The string value the control should have when the control L</is_true>.
-
-=cut
 
 has true_value => (
     is        => 'ro',
@@ -33,11 +16,6 @@ has true_value => (
     default   => 1,
 );
 
-=head2 false_value
-
-The string value the control should have when the control is not L</is_true>.
-
-=cut
 
 has false_value => (
     is        => 'ro',
@@ -45,21 +23,6 @@ has false_value => (
     default   => '',
 );
 
-=head1 METHODS
-
-=head2 is_currently_true
-
-Returns a true value when the C<current_value> is set to L</true_value> or a false value when the C<current_value> is set to L</false_value>.
-
-This method returns C<undef> if it is neither true nor false.
-
-If passed a value, e.g.:
-
-  $self->is_currently_true(1);
-
-This will set the C<current_value>. If a true value is given, the C<value> will be set to L</true_value>. Otherwise, it will cause the C<current_value> to take on the contents of L</false_value>.
-
-=cut
 
 sub _is_it_true {
     my ($self, $value) = @_;
@@ -85,26 +48,12 @@ sub is_currently_true {
     return scalar undef;
 }
 
-=head2 is_true
-
-Returns a true value when the C<value> is set to L</true_value> or a false value when the C<value> is set to L</false_value>.
-
-This method returns C<undef> if it is neither true nor false.
-
-Unlikely L</is_currently_true>, this may not be used as a setter.
-
-=cut
 
 sub is_true {
     my $self = shift;
     return $self->_is_it_true($self->value);
 }
 
-=head2 current_value
-
-We need to handle current value special.
-
-=cut
 
 around current_value => sub {
     my $next  = shift;
@@ -124,11 +73,6 @@ around current_value => sub {
     }
 };
 
-=head2 has_current_value
-
-If the value is true or false, it has a current value. Otherwise, it does not.
-
-=cut
 
 around has_current_value => sub {
     my $next = shift;
@@ -136,17 +80,75 @@ around has_current_value => sub {
     return defined $self->is_currently_true;
 };
 
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Form::Factory::Control::Role::BooleanValue - boolean valued controls
+
+=head1 VERSION
+
+version 0.022
+
+=head1 DESCRIPTION
+
+Controls that implement this role have a boolean value. This say much about how that is actually implemented, just that is has a L</true_value> a L</false_value> and then a flag stating whether the true value or false value is currently selected.
+
+=head1 ATTRIBUTES
+
+=head2 true_value
+
+The string value the control should have when the control L</is_true>.
+
+=head2 false_value
+
+The string value the control should have when the control is not L</is_true>.
+
+=head1 METHODS
+
+=head2 is_currently_true
+
+Returns a true value when the C<current_value> is set to L</true_value> or a false value when the C<current_value> is set to L</false_value>.
+
+This method returns C<undef> if it is neither true nor false.
+
+If passed a value, e.g.:
+
+  $self->is_currently_true(1);
+
+This will set the C<current_value>. If a true value is given, the C<value> will be set to L</true_value>. Otherwise, it will cause the C<current_value> to take on the contents of L</false_value>.
+
+=head2 is_true
+
+Returns a true value when the C<value> is set to L</true_value> or a false value when the C<value> is set to L</false_value>.
+
+This method returns C<undef> if it is neither true nor false.
+
+Unlikely L</is_currently_true>, this may not be used as a setter.
+
+=head2 current_value
+
+We need to handle current value special.
+
+=head2 has_current_value
+
+If the value is true or false, it has a current value. Otherwise, it does not.
+
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
