@@ -1,26 +1,9 @@
 package Form::Factory::Control::Role::Labeled;
-$Form::Factory::Control::Role::Labeled::VERSION = '0.021';
+$Form::Factory::Control::Role::Labeled::VERSION = '0.022';
 use Moose::Role;
 
-=head1 NAME
+# ABSTRACT: labeled controls
 
-Form::Factory::Control::Role::Labeled - labeled controls
-
-=head1 VERSION
-
-version 0.021
-
-=head1 DESCRIPTION
-
-Implemented by any control with a label.
-
-=head1 ATTRIBUTES
-
-=head2 label
-
-The label. By default it is created from the control's name.
-
-=cut
 
 has label => (
     is        => 'ro',
@@ -38,17 +21,41 @@ sub _build_label {
     return $label;
 }
 
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Form::Factory::Control::Role::Labeled - labeled controls
+
+=head1 VERSION
+
+version 0.022
+
+=head1 DESCRIPTION
+
+Implemented by any control with a label.
+
+=head1 ATTRIBUTES
+
+=head2 label
+
+The label. By default it is created from the control's name.
+
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
