@@ -1,5 +1,5 @@
 package Form::Factory::Control::Role::ListValue;
-$Form::Factory::Control::Role::ListValue::VERSION = '0.021';
+$Form::Factory::Control::Role::ListValue::VERSION = '0.022';
 use Moose::Role;
 
 excludes qw( 
@@ -7,13 +7,26 @@ excludes qw(
     Form::Factory::Control::Role::ScalarValue 
 );
 
+# ABSTRACT: list-valued controls
+
+
+use constant default_isa => 'ArrayRef[Str]';
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Control::Role::ListValue - list-valued controls
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 DESCRIPTION
 
@@ -25,21 +38,15 @@ Implemented by control that are multi-values.
 
 List valued controls are "ArrayRef[Str]" by default.
 
-=cut
-
-use constant default_isa => 'ArrayRef[Str]';
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
