@@ -1,14 +1,25 @@
 package Form::Factory::Control::Role::PresetValue;
-$Form::Factory::Control::Role::PresetValue::VERSION = '0.021';
+$Form::Factory::Control::Role::PresetValue::VERSION = '0.022';
 use Moose::Role;
 
+# ABSTRACT: controls with preset values
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Control::Role::PresetValue - controls with preset values
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 DESCRIPTION
 
@@ -16,15 +27,13 @@ This role provides no methods or attributes. It flags the control as one with a
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
