@@ -1,5 +1,5 @@
 package Form::Factory::Control::SelectMany;
-$Form::Factory::Control::SelectMany::VERSION = '0.021';
+$Form::Factory::Control::SelectMany::VERSION = '0.022';
 use Moose;
 
 with qw(
@@ -11,13 +11,61 @@ with qw(
 
 use List::MoreUtils qw( any );
 
+# ABSTRACT: the multi-select control
+
+
+has '+value' => (
+    isa       => 'ArrayRef[Str]',
+);
+
+has '+default_value' => (
+    isa       => 'ArrayRef[Str]',
+    default   => sub { [] },
+);
+
+
+sub current_values { shift->current_value(@_) }
+
+
+sub selected_choices { shift->value(@_) }
+
+sub has_selected_choices { shift->has_value(@_) }
+
+
+sub default_selected_choices { shift->default_value(@_) }
+
+sub has_default_selected_choices { shift->has_default_value(@_) }
+
+
+sub is_choice_selected {
+    my ($self, $choice) = @_;
+
+    return any { $_ eq $choice->value } @{ $self->current_values };
+}
+
+
+around has_current_value => sub {
+    my $next = shift;
+    my $self = shift;
+    return ($self->has_value || $self->has_default_value) 
+        && scalar(@{ $self->current_value }) > 0;
+};
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Control::SelectMany - the multi-select control
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -40,27 +88,12 @@ A select many can be displayed as a multi-select list box or a list of checkboxe
 
 This control implements L<Form::Factory::Control>, L<Form::Factory::Control::Role::AvailableChoices>, L<Form::Factory::Control::Role::Labeled>, L<Form::Factory::Control::Role::ListValue>.
 
-=cut
-
-has '+value' => (
-    isa       => 'ArrayRef[Str]',
-);
-
-has '+default_value' => (
-    isa       => 'ArrayRef[Str]',
-    default   => sub { [] },
-);
-
 =head1 METHODS
 
 =head2 current_values
 
 This is a synonym for C<current_value>.
 
-=cut
-
-sub current_values { shift->current_value(@_) }
-
 =head2 selected_choices
 
 This is a synonym for C<value>.
@@ -69,12 +102,6 @@ This is a synonym for C<value>.
 
 This is a synonyms for C<has_selected_choices>.
 
-=cut
-
-sub selected_choices { shift->value(@_) }
-
-sub has_selected_choices { shift->has_value(@_) }
-
 =head2 default_selected_choices
 
 This is a synonym for C<default_value>.
@@ -83,12 +110,6 @@ This is a synonym for C<default_value>.
 
 This is a synonym for C<has_default_selected_choices>.
 
-=cut
-
-sub default_selected_choices { shift->default_value(@_) }
-
-sub has_default_selected_choices { shift->has_default_value(@_) }
-
 =head2 is_choice_selected
 
   for my $choice (@{ $self->available_choices }) {
@@ -99,39 +120,19 @@ sub has_default_selected_choices { shift->has_default_value(@_) }
 
 This is a helper that is useful while iterating over the available choices in deciding which have been selected.
 
-=cut
-
-sub is_choice_selected {
-    my ($self, $choice) = @_;
-
-    return any { $_ eq $choice->value } @{ $self->current_values };
-}
-
 =head2 has_current_value
 
 It has a current value if one or more values are selected.
 
-=cut
-
-around has_current_value => sub {
-    my $next = shift;
-    my $self = shift;
-    return ($self->has_value || $self->has_default_value) 
-        && scalar(@{ $self->current_value }) > 0;
-};
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-1;
