@@ -1,5 +1,5 @@
 package Form::Factory::Control::SelectOne;
-$Form::Factory::Control::SelectOne::VERSION = '0.021';
+$Form::Factory::Control::SelectOne::VERSION = '0.022';
 use Moose;
 
 with qw(
@@ -9,13 +9,32 @@ with qw(
     Form::Factory::Control::Role::ScalarValue
 );
 
+# ABSTRACT: A control for selecting a single item
+
+
+has '+value' => (
+    isa       => 'Str',
+);
+
+has '+default_value' => (
+    isa       => 'Str',
+);
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Control::SelectOne - A control for selecting a single item
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -35,27 +54,15 @@ version 0.021
 
 A select control that allows a single selection. A list of radio buttons or a drop-down box would be appropriate.
 
-=cut
-
-has '+value' => (
-    isa       => 'Str',
-);
-
-has '+default_value' => (
-    isa       => 'Str',
-);
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
