@@ -1,5 +1,5 @@
 package Form::Factory::Control::Value;
-$Form::Factory::Control::Value::VERSION = '0.021';
+$Form::Factory::Control::Value::VERSION = '0.022';
 use Moose;
 
 with qw(
@@ -10,13 +10,36 @@ with qw(
     Form::Factory::Control::Role::ScalarValue
 );
 
+# ABSTRACT: A read-only value control
+
+
+has '+value' => (
+    required  => 1,
+);
+
+
+has is_visible => (
+    is        => 'ro',
+    isa       => 'Bool',
+    required  => 1,
+    default   => 0,
+);
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Control::Value - A read-only value control
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -37,36 +60,19 @@ This control implements L<Form::Factory::Control>, L<Form::Factory::Control::Rol
 
 =head1 ATTRIBUTES
 
-=cut
-
-has '+value' => (
-    required  => 1,
-);
-
 =head2 is_visible
 
 Set to true if the read-only value should be displayed.
 
-=cut
-
-has is_visible => (
-    is        => 'ro',
-    isa       => 'Bool',
-    required  => 1,
-    default   => 0,
-);
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
