@@ -1,5 +1,5 @@
 package Form::Factory::Feature::Control::MatchAvailableChoices;
-$Form::Factory::Feature::Control::MatchAvailableChoices::VERSION = '0.021';
+$Form::Factory::Feature::Control::MatchAvailableChoices::VERSION = '0.022';
 use Moose;
 
 with qw( 
@@ -11,39 +11,8 @@ with qw(
 
 use Carp ();
 
-=head1 NAME
+# ABSTRACT: Check for choice availability
 
-Form::Factory::Feature::Control::MatchAvailableChoices - Check for choice availability
-
-=head1 VERSION
-
-version 0.021
-
-=head1 SYNOPSIS
-
-  has_control time_zone => (
-      control => 'select_one',
-      options => {
-          available_choices => [
-              map { Form::Factory::Control::Choice->new($_) } qw( PST MST CST EST )
-          ],
-      },
-      features => {
-          match_available_choices => 1,
-      },
-  );
-
-=head1 DESCRIPTION
-
-Verifies that the value set for the control matches one of the available choices.
-
-=head1 METHODS
-
-=head2 check_control
-
-Verifies that the control does the L<Form::Factory::Control::Role::AvailableChoices>.
-
-=cut
 
 sub check_control {
     my ($self, $control) = @_;
@@ -52,11 +21,6 @@ sub check_control {
         unless $control->does('Form::Factory::Control::Role::AvailableChoices');
 }
 
-=head2 check
-
-Verifies that the value or values set match one or more of the available values.
-
-=cut
 
 sub check {
     my $self    = shift;
@@ -90,17 +54,59 @@ sub check {
     $self->result->is_valid(1) unless $self->result->is_validated;
 }
 
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Form::Factory::Feature::Control::MatchAvailableChoices - Check for choice availability
+
+=head1 VERSION
+
+version 0.022
+
+=head1 SYNOPSIS
+
+  has_control time_zone => (
+      control => 'select_one',
+      options => {
+          available_choices => [
+              map { Form::Factory::Control::Choice->new($_) } qw( PST MST CST EST )
+          ],
+      },
+      features => {
+          match_available_choices => 1,
+      },
+  );
+
+=head1 DESCRIPTION
+
+Verifies that the value set for the control matches one of the available choices.
+
+=head1 METHODS
+
+=head2 check_control
+
+Verifies that the control does the L<Form::Factory::Control::Role::AvailableChoices>.
+
+=head2 check
+
+Verifies that the value or values set match one or more of the available values.
+
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
