@@ -1,5 +1,5 @@
 package Form::Factory::Feature::Control::MatchCode;
-$Form::Factory::Feature::Control::MatchCode::VERSION = '0.021';
+$Form::Factory::Feature::Control::MatchCode::VERSION = '0.022';
 use Moose;
 
 with qw( 
@@ -11,13 +11,47 @@ with qw(
 
 use Carp ();
 
+# ABSTRACT: Greps the control value for correctness
+
+
+has code => (
+    is        => 'ro',
+    isa       => 'CodeRef',
+    required  => 1,
+);
+
+
+sub check_control { }
+
+
+sub check {
+    my $self    = shift;
+    my $control = $self->control;
+    my $value   = $control->current_value;
+
+    unless ($self->code->($value)) {
+        $self->control_error('the %s is not correct');
+        $self->result->is_valid(0);
+    }
+
+    $self->result->is_valid(1) unless $self->result->is_validated;
+}
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::Control::MatchCode - Greps the control value for correctness
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -41,54 +75,25 @@ Runs the control value against a code reference during the check. If that code r
 
 This is the code reference. It should expect a single argument to be passed, which is the value to check.
 
-=cut
-
-has code => (
-    is        => 'ro',
-    isa       => 'CodeRef',
-    required  => 1,
-);
-
 =head1 METHODS
 
 =head2 check_control
 
 No op.
 
-=cut
-
-sub check_control { }
-
 =head2 check
 
 Does the work of running the given subroutine over the control value and reports an error if the code reference runs and returns a false value.
 
-=cut
-
-sub check {
-    my $self    = shift;
-    my $control = $self->control;
-    my $value   = $control->current_value;
-
-    unless ($self->code->($value)) {
-        $self->control_error('the %s is not correct');
-        $self->result->is_valid(0);
-    }
-
-    $self->result->is_valid(1) unless $self->result->is_validated;
-}
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
