@@ -1,5 +1,5 @@
 package Form::Factory::Feature::Control::Required;
-$Form::Factory::Feature::Control::Required::VERSION = '0.021';
+$Form::Factory::Feature::Control::Required::VERSION = '0.022';
 use Moose;
 
 with qw( 
@@ -11,13 +11,41 @@ with qw(
 
 use Carp ();
 
+# ABSTRACT: Makes sure a value is set on a control
+
+
+sub check_control { }
+
+
+sub check {
+    my $self    = shift;
+    my $control = $self->control;
+
+    if ($control->has_current_value) {
+        $self->result->is_valid(1);
+    }
+
+    else {
+        $self->control_error('the %s is required');
+        $self->result->is_valid(0);
+    }
+}
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::Control::Required - Makes sure a value is set on a control
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -38,41 +66,19 @@ Reports a check error if the required value is not set. On scalar value controls
 
 No op.
 
-=cut
-
-sub check_control { }
-
 =head2 check
 
 Reports an error if a scalar value does not have a length greater than 0. Reports an error if a list value has 0 items in the list.
 
-=cut
-
-sub check {
-    my $self    = shift;
-    my $control = $self->control;
-
-    if ($control->has_current_value) {
-        $self->result->is_valid(1);
-    }
-
-    else {
-        $self->control_error('the %s is required');
-        $self->result->is_valid(0);
-    }
-}
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
