@@ -1,5 +1,5 @@
 package Form::Factory::Feature::RequireNoneOrAll;
-$Form::Factory::Feature::RequireNoneOrAll::VERSION = '0.021';
+$Form::Factory::Feature::RequireNoneOrAll::VERSION = '0.022';
 use Moose;
 
 use Moose::Util qw( english_list );
@@ -11,13 +11,77 @@ with qw(
 
 use Carp ();
 
+# ABSTRACT: if one control has a value, all should
+
+
+has groups => (
+    is        => 'ro',
+    isa       => 'HashRef[ArrayRef[Str]]',
+    required  => 1,
+);
+
+
+sub check {
+    my $self   = shift;
+    my $action = $self->action;
+
+    GROUP: for my $control_names (values %{ $self->groups }) {
+        my $has_a_value    = 0;
+        my $has_all_values = 1;
+        my $valued_control;
+
+        CONTROL: for my $name (@$control_names) {
+            my $control = $action->controls->{$name};
+
+            my $has_current_value = $control->has_current_value;
+            $has_a_value        ||= $has_current_value;
+            $has_all_values     &&= $has_current_value;
+
+            $valued_control = $name if $has_current_value;
+
+            if ($has_a_value and not $has_all_values) {
+                $self->result->is_valid(0);
+                $self->result->error(
+                    sprintf('if you enter a value in %s you must enter a value for %s',
+                       $self->_control_label($valued_control), 
+                       english_list(map { $self->_control_label($_) } @$control_names),
+                    )
+                );
+                next GROUP;
+            }
+        }
+    }
+
+    $self->result->is_valid(1) unless $self->result->is_validated;
+}
+
+sub _control_label {
+    my ($self, $name) = @_;
+    my $control = $self->action->controls->{$name};
+
+    my $control_label 
+        = $control->does('Form::Factory::Control::Role::Labeled') ? $control->label
+        :                                                           $control->name
+        ;
+
+    return $control_label;
+}
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::RequireNoneOrAll - if one control has a value, all should
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -67,79 +131,21 @@ This is how the control groups are configured. Each key is used to name a contro
 
 At this time, the control group names are ignored, but might be used in the future for linking additional settings together.
 
-=cut
-
-has groups => (
-    is        => 'ro',
-    isa       => 'HashRef[ArrayRef[Str]]',
-    required  => 1,
-);
-
 =head1 METHODS
 
 =head2 check
 
 This runs the checks to make sure that for each group of controls, either all have a value or none do.
 
-=cut
-
-sub check {
-    my $self   = shift;
-    my $action = $self->action;
-
-    GROUP: for my $control_names (values %{ $self->groups }) {
-        my $has_a_value    = 0;
-        my $has_all_values = 1;
-        my $valued_control;
-
-        CONTROL: for my $name (@$control_names) {
-            my $control = $action->controls->{$name};
-
-            my $has_current_value = $control->has_current_value;
-            $has_a_value        ||= $has_current_value;
-            $has_all_values     &&= $has_current_value;
-
-            $valued_control = $name if $has_current_value;
-
-            if ($has_a_value and not $has_all_values) {
-                $self->result->is_valid(0);
-                $self->result->error(
-                    sprintf('if you enter a value in %s you must enter a value for %s',
-                       $self->_control_label($valued_control), 
-                       english_list(map { $self->_control_label($_) } @$control_names),
-                    )
-                );
-                next GROUP;
-            }
-        }
-    }
-
-    $self->result->is_valid(1) unless $self->result->is_validated;
-}
-
-sub _control_label {
-    my ($self, $name) = @_;
-    my $control = $self->action->controls->{$name};
-
-    my $control_label 
-        = $control->does('Form::Factory::Control::Role::Labeled') ? $control->label
-        :                                                           $control->name
-        ;
-
-    return $control_label;
-}
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
