@@ -1,16 +1,27 @@
 package Form::Factory::Feature::Role::BuildAttribute;
-$Form::Factory::Feature::Role::BuildAttribute::VERSION = '0.021';
+$Form::Factory::Feature::Role::BuildAttribute::VERSION = '0.022';
 use Moose::Role;
 
 requires qw( build_attribute );
 
+# ABSTRACT: control features that modify the action attribute
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::Role::BuildAttribute - control features that modify the action attribute
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -65,15 +76,13 @@ The C<$attr> is the arguments that are about to be passed to the attribute const
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
