@@ -1,16 +1,27 @@
 package Form::Factory::Feature::Role::Check;
-$Form::Factory::Feature::Role::Check::VERSION = '0.021';
+$Form::Factory::Feature::Role::Check::VERSION = '0.022';
 use Moose::Role;
 
 requires qw( check );
 
+# ABSTRACT: features that check control values
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::Role::Check - features that check control values
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -53,15 +64,13 @@ This method is passed no arguments other than the object it is being called on.
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
