@@ -1,16 +1,27 @@
 package Form::Factory::Feature::Role::Clean;
-$Form::Factory::Feature::Role::Clean::VERSION = '0.021';
+$Form::Factory::Feature::Role::Clean::VERSION = '0.022';
 use Moose::Role;
 
 requires qw( clean );
 
+# ABSTRACT: features that clean up control values
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::Role::Clean - features that clean up control values
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -49,15 +60,13 @@ The method will receive no arguments except the object it is called upon and the
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
