@@ -1,16 +1,40 @@
 package Form::Factory::Feature::Role::Control;
-$Form::Factory::Feature::Role::Control::VERSION = '0.021';
+$Form::Factory::Feature::Role::Control::VERSION = '0.022';
 use Moose::Role;
 
 requires qw( check_control );
 
+# ABSTRACT: Form features tied to particular controls
+
+
+has control => (
+    is          => 'ro',
+    does        => 'Form::Factory::Control',
+    required    => 1,
+    weak_ref    => 1,
+    initializer => sub {
+        my ($self, $value, $set, $attr) = @_;
+        $self->check_control($value);
+        $set->($value);
+    },
+);
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::Role::Control - Form features tied to particular controls
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -81,20 +105,6 @@ This role is required for any feature attached directly to a control using C<has
 
 This is the control object the feature has been attached to.
 
-=cut
-
-has control => (
-    is          => 'ro',
-    does        => 'Form::Factory::Control',
-    required    => 1,
-    weak_ref    => 1,
-    initializer => sub {
-        my ($self, $value, $set, $attr) = @_;
-        $self->check_control($value);
-        $set->($value);
-    },
-);
-
 =head1 ROLE METHODS
 
 =head2 check_control
@@ -115,15 +125,13 @@ The return value of this method is ignored. If the control is incompatible with
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
