@@ -1,16 +1,61 @@
 package Form::Factory::Feature::Role::CustomControlMessage;
-$Form::Factory::Feature::Role::CustomControlMessage::VERSION = '0.021';
+$Form::Factory::Feature::Role::CustomControlMessage::VERSION = '0.022';
 use Moose::Role;
 
 with qw( Form::Factory::Feature::Role::CustomMessage );
 
+# ABSTRACT: control features with custom messages
+
+
+sub format_message {
+    my $self    = shift;
+    my $message = $self->message || shift;
+    my $control = $self->control;
+
+    my $control_label 
+        = $control->does('Form::Factory::Control::Role::Labeled') ? $control->label
+        :                                                           $control->name
+        ;
+
+    sprintf $message, $control_label;
+}
+
+
+sub control_info {
+    my $self    = shift;
+    my $message = $self->format_message(shift);
+    $self->result->field_info($self->control->name, $message);
+}
+
+
+sub control_warning {
+    my $self = shift;
+    my $message = $self->format_message(shift);
+    $self->result->field_warning($self->control->name, $message);
+}
+
+
+sub control_error {
+    my $self = shift;
+    my $message = $self->format_message(shift);
+    $self->result->field_error($self->control->name, $message);
+}
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::Role::CustomControlMessage - control features with custom messages
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -36,69 +81,27 @@ A control feature may consume this role in order to allow the user to specify a
 
 Given a message containing a single C<%s> placeholder, it fills that placeholder with the control's label. If the control does not implement L<Form::Factory::Control::Role::Labeled>, the control's name is used instead.
 
-=cut
-
-sub format_message {
-    my $self    = shift;
-    my $message = $self->message || shift;
-    my $control = $self->control;
-
-    my $control_label 
-        = $control->does('Form::Factory::Control::Role::Labeled') ? $control->label
-        :                                                           $control->name
-        ;
-
-    sprintf $message, $control_label;
-}
-
 =head2 control_info
 
 Reports an informational message automatically filtered through L</format_message>.
 
-=cut
-
-sub control_info {
-    my $self    = shift;
-    my $message = $self->format_message(shift);
-    $self->result->field_info($self->control->name, $message);
-}
-
 =head2 control_warning
 
 Reports a warning automatically filtered through L</format_message>.
 
-=cut
-
-sub control_warning {
-    my $self = shift;
-    my $message = $self->format_message(shift);
-    $self->result->field_warning($self->control->name, $message);
-}
-
 =head2 control_error
 
 Reports an error automatically filtered through L</format_error>.
 
-=cut
-
-sub control_error {
-    my $self = shift;
-    my $message = $self->format_message(shift);
-    $self->result->field_error($self->control->name, $message);
-}
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-1;
