@@ -1,14 +1,52 @@
 package Form::Factory::Feature::Role::CustomMessage;
-$Form::Factory::Feature::Role::CustomMessage::VERSION = '0.021';
+$Form::Factory::Feature::Role::CustomMessage::VERSION = '0.022';
 use Moose::Role;
 
+# ABSTRACT: features with custom messages
+
+
+has message => (
+    is        => 'ro',
+    isa       => 'Str',
+    predicate => 'has_message',
+);
+
+
+sub feature_info {
+    my $self    = shift;
+    my $message = $self->message || shift;
+    $self->result->info($message);
+}
+
+
+sub feature_warning {
+    my $self    = shift;
+    my $message = $self->message || shift;
+    $self->result->warning($message);
+}
+
+
+sub feature_error {
+    my $self    = shift;
+    my $message = $self->message || shift;
+    $self->result->error($message);
+}
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Feature::Role::CustomMessage - features with custom messages
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 DESCRIPTION
 
@@ -22,14 +60,6 @@ This is a custom error message for failures. This message is used instead of the
 
 This is inadequate. It should be fixed in the future.
 
-=cut
-
-has message => (
-    is        => 'ro',
-    isa       => 'Str',
-    predicate => 'has_message',
-);
-
 =head1 METHODS
 
 =head2 feature_info
@@ -38,54 +68,27 @@ has message => (
 
 Record an info feature message.
 
-=cut
-
-sub feature_info {
-    my $self    = shift;
-    my $message = $self->message || shift;
-    $self->result->info($message);
-}
-
 =head2 feature_warning
 
   $feature->feature_warning($message);
 
 Record a warning feature message.
 
-=cut
-
-sub feature_warning {
-    my $self    = shift;
-    my $message = $self->message || shift;
-    $self->result->warning($message);
-}
-
 =head2 feature_error
 
   $feature->feature_error($message);
 
 Record an error feature message.
 
-=cut
-
-sub feature_error {
-    my $self    = shift;
-    my $message = $self->message || shift;
-    $self->result->error($message);
-}
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-1;
