@@ -1,5 +1,5 @@
 package Form::Factory::Interface;
-$Form::Factory::Interface::VERSION = '0.021';
+$Form::Factory::Interface::VERSION = '0.022';
 use Moose::Role;
 
 use Carp ();
@@ -8,13 +8,53 @@ use Form::Factory::Stasher::Memory;
 
 requires qw( render_control consume_control );
 
+# ABSTRACT: Role for form interface implementations
+
+
+has stasher => (
+    is        => 'ro',
+    does      => 'Form::Factory::Stasher',
+    required  => 1,
+    default   => sub { Form::Factory::Stasher::Memory->new },
+    handles   => [ qw( stash unstash ) ],
+);
+
+
+sub new_action {
+    my ($self, $class_name, $args) = @_;
+
+    Class::Load::load_class($class_name)
+        or Carp::croak("cannot load $class_name: $@");
+
+    return $class_name->new( %$args, form_interface => $self );
+}
+
+
+sub new_control {
+    my ($self, $name, $args) = @_;
+
+    my $class_name = Form::Factory->control_class($name);
+    return unless $class_name;
+
+    return $class_name->new($args);
+}
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Interface - Role for form interface implementations
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -48,16 +88,6 @@ Defines the contract form interface classes must fulfill.
 
 A place for remembering things.
 
-=cut
-
-has stasher => (
-    is        => 'ro',
-    does      => 'Form::Factory::Stasher',
-    required  => 1,
-    default   => sub { Form::Factory::Stasher::Memory->new },
-    handles   => [ qw( stash unstash ) ],
-);
-
 =head1 METHODS
 
 =head2 stash
@@ -72,34 +102,12 @@ See L<Form::Factory::Stash>.
 
 Given the name of an action class, it initializes the class for use with this interface. The C<%options> are passed to the constructor.
 
-=cut
-
-sub new_action {
-    my ($self, $class_name, $args) = @_;
-
-    Class::Load::load_class($class_name)
-        or Carp::croak("cannot load $class_name: $@");
-
-    return $class_name->new( %$args, form_interface => $self );
-}
-
 =head2 new_control
 
   my $control = $interface->new_control($name, \%options);
 
 Given the short name for a control and a hash reference of initialization arguments, return a fully initialized control.
 
-=cut
-
-sub new_control {
-    my ($self, $name, $args) = @_;
-
-    my $class_name = Form::Factory->control_class($name);
-    return unless $class_name;
-
-    return $class_name->new($args);
-}
-
 =head1 ROLE METHODS
 
 The following methods need to implement the following methods.
@@ -162,15 +170,13 @@ L<Form::Factory::Action>, L<Form::Factory::Control>, L<Form::Factory::Stasher>
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp, C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
