@@ -1,54 +1,13 @@
 package Form::Factory::Interface::CLI;
-$Form::Factory::Interface::CLI::VERSION = '0.021';
+$Form::Factory::Interface::CLI::VERSION = '0.022';
 use Moose;
 
 with qw( Form::Factory::Interface );
 
 use Carp ();
 
-=head1 NAME
+# ABSTRACT: Command-line interface builder for form factory
 
-Form::Factory::Interface::CLI - Command-line interface builder for form factory
-
-=head1 VERSION
-
-version 0.021
-
-=head1 SYNOPSIS
-
-  #/usr/bin/perl
-  use strict;
-  use warnings;
-
-  use Form::Factory;
-
-  my $cli = Form::Factory->new_interface('CLI');
-  my $action = $cli->new_action(shift @ARGV);
-  
-  $action->consume_and_clean_and_check_and_process;
-
-  if ($action->is_valid and $action->is_success) {
-      print "done.\n";
-  }
-  else {
-      my $messages = $action->results->all_messages;
-      print $messages;
-      print "usage: $0 OPTIONS\n\n";
-      print "Options:\n";
-      $action->render;
-  }
-
-=head1 DESCRIPTION
-
-Provides a simple interface for building command-line tools that manipulate actions.
-
-=head1 ATTRIBUTES
-
-=head2 renderer
-
-This is a subroutine responsible for returning the usage parameters back to the user. The default prints to C<STDOUT>.
-
-=cut
 
 has renderer => (
     is        => 'ro',
@@ -57,11 +16,6 @@ has renderer => (
     default   => sub { sub { print @_ } },
 );
 
-=head2 get_args
-
-This is a subroutine responsible for return a list of command-line arguments. The default implementation returns a reference to C<@ARGV>.
-
-=cut
 
 has get_args => (
     is        => 'ro',
@@ -70,11 +24,6 @@ has get_args => (
     default   => sub { sub { \@ARGV } },
 );
 
-=head2 get_file
-
-This is a subroutine responsible for returning the contents of files used on the command-line. It is passed the interface object and then the name of the file to load. The default implementation slurps up the named file or, in the case of the name begin "-", returns the contents of C<STDIN>.
-
-=cut
 
 has get_file => (
     is        => 'ro',
@@ -97,13 +46,6 @@ has get_file => (
     },
 );
 
-=head1 METHODS
-
-=head2 render_control
-
-Prints a usage line for each control.
-
-=cut
 
 sub render_control {
     my ($self, $control, %options) = @_;
@@ -135,11 +77,6 @@ sub render_control {
     );
 }
 
-=head2 consume_control
-
-Consumes the command-line arguments and files specified on the command-line to fill in the action.
-
-=cut
 
 sub consume_control {
     my ($self, $control, %options) = @_;
@@ -188,17 +125,83 @@ sub consume_control {
     }
 }
 
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Form::Factory::Interface::CLI - Command-line interface builder for form factory
+
+=head1 VERSION
+
+version 0.022
+
+=head1 SYNOPSIS
+
+  #/usr/bin/perl
+  use strict;
+  use warnings;
+
+  use Form::Factory;
+
+  my $cli = Form::Factory->new_interface('CLI');
+  my $action = $cli->new_action(shift @ARGV);
+  
+  $action->consume_and_clean_and_check_and_process;
+
+  if ($action->is_valid and $action->is_success) {
+      print "done.\n";
+  }
+  else {
+      my $messages = $action->results->all_messages;
+      print $messages;
+      print "usage: $0 OPTIONS\n\n";
+      print "Options:\n";
+      $action->render;
+  }
+
+=head1 DESCRIPTION
+
+Provides a simple interface for building command-line tools that manipulate actions.
+
+=head1 ATTRIBUTES
+
+=head2 renderer
+
+This is a subroutine responsible for returning the usage parameters back to the user. The default prints to C<STDOUT>.
+
+=head2 get_args
+
+This is a subroutine responsible for return a list of command-line arguments. The default implementation returns a reference to C<@ARGV>.
+
+=head2 get_file
+
+This is a subroutine responsible for returning the contents of files used on the command-line. It is passed the interface object and then the name of the file to load. The default implementation slurps up the named file or, in the case of the name begin "-", returns the contents of C<STDIN>.
+
+=head1 METHODS
+
+=head2 render_control
+
+Prints a usage line for each control.
+
+=head2 consume_control
+
+Consumes the command-line arguments and files specified on the command-line to fill in the action.
+
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
