@@ -1,5 +1,5 @@
 package Form::Factory::Interface::HTML;
-$Form::Factory::Interface::HTML::VERSION = '0.021';
+$Form::Factory::Interface::HTML::VERSION = '0.022';
 use Moose;
 
 with qw( Form::Factory::Interface );
@@ -16,48 +16,8 @@ use Form::Factory::Interface::HTML::Widget::Select;
 use Form::Factory::Interface::HTML::Widget::Span;
 use Form::Factory::Interface::HTML::Widget::Textarea;
 
-=head1 NAME
+# ABSTRACT: Simple HTML form interface
 
-Form::Factory::Interface::HTML - Simple HTML form interface
-
-=head1 VERSION
-
-version 0.021
-
-=head1 SYNOPSIS
-
-  use Form::Factory;
-
-  my $q = CGI->new;
-  my $html = '<form>';
-
-  my $form = Form::Factory->new(HTML => {
-      renderer => sub { $html .= join('', @_) },
-      consumer => sub { shift->Vars },
-  });
-
-  my $action = $form->new_action('MyApp::Action::Foo');
-  $action->consume_and_clean_and_check_and_process( request => $q );
-  $action->render;
-
-  $html .= '</form>';
-
-  print $q->header('text/html');
-  print $html;
-
-=head1 DESCRIPTION
-
-This renders plain HTML forms and consumes value from a hash.
-
-=head1 ATTRIBUTES
-
-=head2 renderer
-
-This is a code reference responsible for printing the HTML elements. The HTML for the controls is passed to this subroutine as a string. The default implementation just prints to the screen.
-
-  sub { print @_ }
-
-=cut
 
 has renderer => (
     is        => 'ro',
@@ -66,11 +26,6 @@ has renderer => (
     default   => sub { sub { print @_ } },
 );
 
-=head2 consumer
-
-This is a code reference responsible for taking the request object and turning it into a hash reference of values passed in from the HTTP request. The value passed in is the value passed as the C<request> parameter to L<Form::Factory::Action/consume>.
-
-=cut
 
 has consumer => (
     is        => 'ro',
@@ -79,13 +34,6 @@ has consumer => (
     default   => sub { sub { $_[0] } },
 );
 
-=head1 METHODS
-
-=head2 new_widget_for_control
-
-Returns a L<Form::Factory::Interface::HTML::Widget> implementation for the given control.
-
-=cut
 
 sub new_widget_for_control {
     my $self    = shift;
@@ -181,11 +129,6 @@ sub _alerts_for_control {
     return @items;
 }
 
-=head2 new_widget_for_button
-
-Returns a widget for a L<Form::Factory::Control::Button>.
-
-=cut
 
 sub new_widget_for_button {
     my ($self, $control) = @_;
@@ -193,11 +136,6 @@ sub new_widget_for_button {
     return _input($control->name, 'button', 'submit', $control->label);
 }
 
-=head2 new_widget_for_checkbox
-
-Returns a widget for a L<Form::Factory::Control::Checkbox>.
-
-=cut
 
 sub new_widget_for_checkbox {
     my ($self, $control, @alerts) = @_;
@@ -210,11 +148,6 @@ sub new_widget_for_checkbox {
     );
 }
 
-=head2 new_widget_for_fulltext
-
-Returns a widget for a L<Form::Factory::Control::FullText>.
-
-=cut
 
 sub new_widget_for_fulltext {
     my ($self, $control, @alerts) = @_;
@@ -232,11 +165,6 @@ sub new_widget_for_fulltext {
     );
 }
 
-=head2 new_widget_for_password
-
-Returns a widget for a L<Form::Factory::Control::Password>.
-
-=cut
 
 sub new_widget_for_password {
     my ($self, $control, @alerts) = @_;
@@ -249,11 +177,6 @@ sub new_widget_for_password {
     );
 }
 
-=head2 new_widget_for_selectmany
-
-Returns a widget for a L<Form::Factory::Control::SelectMany>.
-
-=cut
 
 sub new_widget_for_selectmany {
     my ($self, $control, @alerts) = @_;
@@ -278,11 +201,6 @@ sub new_widget_for_selectmany {
     );
 }
 
-=head2 new_widget_for_selectone
-
-Returns a widget for a L<Form::Factory::Control::SelectOne>.
-
-=cut
 
 sub new_widget_for_selectone {
     my ($self, $control, @alerts) = @_;
@@ -302,11 +220,6 @@ sub new_widget_for_selectone {
     );
 }
 
-=head2 new_widget_for_text
-
-Returns a widget for a L<Form::Factory::Control::Text>.
-
-=cut
 
 sub new_widget_for_text {
     my ($self, $control, @alerts) = @_;
@@ -319,11 +232,6 @@ sub new_widget_for_text {
     );
 }
 
-=head2 new_widget_for_value
-
-Returns a widget for a L<Form::Factory::Control::Value>.
-
-=cut
 
 sub new_widget_for_value {
     my ($self, $control, @alerts) = @_;
@@ -343,11 +251,6 @@ sub new_widget_for_value {
     return;
 }
 
-=head2 render_control
-
-Renders the widget for the given control.
-
-=cut
 
 sub render_control {
     my ($self, $control, %options) = @_;
@@ -357,11 +260,6 @@ sub render_control {
     $self->renderer->($widget->render);
 }
 
-=head2 consume_control
-
-Consumes values using the widget for the given control.
-
-=cut
 
 sub consume_control {
     my ($self, $control, %options) = @_;
@@ -378,6 +276,107 @@ sub consume_control {
     $control->current_value( $params->{ $control->name } );
 }
 
+
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Form::Factory::Interface::HTML - Simple HTML form interface
+
+=head1 VERSION
+
+version 0.022
+
+=head1 SYNOPSIS
+
+  use Form::Factory;
+
+  my $q = CGI->new;
+  my $html = '<form>';
+
+  my $form = Form::Factory->new(HTML => {
+      renderer => sub { $html .= join('', @_) },
+      consumer => sub { shift->Vars },
+  });
+
+  my $action = $form->new_action('MyApp::Action::Foo');
+  $action->consume_and_clean_and_check_and_process( request => $q );
+  $action->render;
+
+  $html .= '</form>';
+
+  print $q->header('text/html');
+  print $html;
+
+=head1 DESCRIPTION
+
+This renders plain HTML forms and consumes value from a hash.
+
+=head1 ATTRIBUTES
+
+=head2 renderer
+
+This is a code reference responsible for printing the HTML elements. The HTML for the controls is passed to this subroutine as a string. The default implementation just prints to the screen.
+
+  sub { print @_ }
+
+=head2 consumer
+
+This is a code reference responsible for taking the request object and turning it into a hash reference of values passed in from the HTTP request. The value passed in is the value passed as the C<request> parameter to L<Form::Factory::Action/consume>.
+
+=head1 METHODS
+
+=head2 new_widget_for_control
+
+Returns a L<Form::Factory::Interface::HTML::Widget> implementation for the given control.
+
+=head2 new_widget_for_button
+
+Returns a widget for a L<Form::Factory::Control::Button>.
+
+=head2 new_widget_for_checkbox
+
+Returns a widget for a L<Form::Factory::Control::Checkbox>.
+
+=head2 new_widget_for_fulltext
+
+Returns a widget for a L<Form::Factory::Control::FullText>.
+
+=head2 new_widget_for_password
+
+Returns a widget for a L<Form::Factory::Control::Password>.
+
+=head2 new_widget_for_selectmany
+
+Returns a widget for a L<Form::Factory::Control::SelectMany>.
+
+=head2 new_widget_for_selectone
+
+Returns a widget for a L<Form::Factory::Control::SelectOne>.
+
+=head2 new_widget_for_text
+
+Returns a widget for a L<Form::Factory::Control::Text>.
+
+=head2 new_widget_for_value
+
+Returns a widget for a L<Form::Factory::Control::Value>.
+
+=head2 render_control
+
+Renders the widget for the given control.
+
+=head2 consume_control
+
+Consumes values using the widget for the given control.
+
 =head1 CAVEATS
 
 When I initially implemented this, using the widget classes made sense. However, the API has changed in some subtle ways since then. Originally, widgets were a required piece of the factory API, but they are not anymore. As such, they don't make nearly as much sense as they once did.
@@ -390,16 +389,13 @@ L<Form::Factory::Interface>
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-1;
