@@ -1,28 +1,11 @@
 package Form::Factory::Interface::HTML::Widget;
-$Form::Factory::Interface::HTML::Widget::VERSION = '0.021';
+$Form::Factory::Interface::HTML::Widget::VERSION = '0.022';
 use Moose::Role;
 
 requires qw( render_control consume_control );
 
-=head1 NAME
+# ABSTRACT: rendering/consuming HTML controls
 
-Form::Factory::Interface::HTML::Widget - rendering/consuming HTML controls
-
-=head1 VERSION
-
-version 0.021
-
-=head1 DESCRIPTION
-
-Widget is the low-level API for rendering and processing HTML/HTTP form elements.
-
-=head1 ATTRIBUTES
-
-=head2 alternate_renderer
-
-If the renderer needs to be customized, provide a custom renderer here. This is a code reference that is passed the control and options like the usual renderer method.
-
-=cut
 
 has alternate_renderer => (
     is        => 'rw',
@@ -30,11 +13,6 @@ has alternate_renderer => (
     predicate => 'has_alternate_renderer',
 );
 
-=head2 alternate_consumer
-
-If the control needes to be consumed in a custom way, you can add that here. This is a code reference that is passed the control and options like the usual consumer method.
-
-=cut
 
 has alternate_consumer => (
     is        => 'rw',
@@ -42,13 +20,6 @@ has alternate_consumer => (
     predicate => 'has_alternate_consumer',
 );
 
-=head1 METHODS
-
-=head2 render
-
-Renders the HTML required to use this method.
-
-=cut
 
 sub render {
     my $self     = shift;
@@ -61,11 +32,6 @@ sub render {
     }
 }
 
-=head2 consume
-
-Consumes the value from the request.
-
-=cut
 
 sub consume {
     my $self = shift;
@@ -78,6 +44,47 @@ sub consume {
     }
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Form::Factory::Interface::HTML::Widget - rendering/consuming HTML controls
+
+=head1 VERSION
+
+version 0.022
+
+=head1 DESCRIPTION
+
+Widget is the low-level API for rendering and processing HTML/HTTP form elements.
+
+=head1 ATTRIBUTES
+
+=head2 alternate_renderer
+
+If the renderer needs to be customized, provide a custom renderer here. This is a code reference that is passed the control and options like the usual renderer method.
+
+=head2 alternate_consumer
+
+If the control needes to be consumed in a custom way, you can add that here. This is a code reference that is passed the control and options like the usual consumer method.
+
+=head1 METHODS
+
+=head2 render
+
+Renders the HTML required to use this method.
+
+=head2 consume
+
+Consumes the value from the request.
+
 =head1 ROLE METHODS
 
 These methods must be implemented by role implementers.
@@ -92,15 +99,13 @@ Given consumer options, process the input.
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp, C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
