@@ -1,5 +1,5 @@
 package Form::Factory::Processor;
-$Form::Factory::Processor::VERSION = '0.021';
+$Form::Factory::Processor::VERSION = '0.022';
 use Moose;
 use Moose::Exporter;
 
@@ -18,13 +18,112 @@ Moose::Exporter->setup_import_methods(
     also      => 'Moose',
 );
 
+# ABSTRACT: Moos-ish helper for action classes
+
+
+sub init_meta {
+    my $package = shift;
+    my %options = @_;
+
+    Moose->init_meta(%options);
+
+    my $meta = Moose::Util::MetaRole::apply_metaroles(
+        for             => $options{for_class},
+        class_metaroles => {
+            class => [ 'Form::Factory::Action::Meta::Class' ],
+        },
+    );
+
+    Moose::Util::apply_all_roles(
+        $options{for_class}, 'Form::Factory::Action',
+    );
+
+    return $meta;
+}
+
+
+sub _setup_control_defaults {
+    my $meta = shift;
+    my $name = shift;
+    my $args = @_ == 1 ? shift : { @_ };
+
+    # Setup default unless this is an inherited control attribute
+    unless ($name =~ /^\+/) {
+        $args->{control}  ||= 'text';
+        $args->{options}  ||= {};
+        $args->{features} ||= {};
+        $args->{traits}   ||= [];
+
+        $args->{is}       ||= 'ro';
+        $args->{isa}      ||= Form::Factory->control_class($args->{control})->default_isa;
+
+        unshift @{ $args->{traits} }, 'Form::Control';
+
+    }
+
+    Carp::croak(qq{the "required" setting is used on $name, but is forbidden on controls})
+        if $args->{required};
+
+    for my $value (values %{ $args->{features} }) {
+        $value = {} if $value and not ref $value;
+    }
+
+    $args->{__meta} = $meta;
+
+    return ($meta, $name, $args);
+}
+
+sub has_control {
+    my ($meta, $name, $args) = _setup_control_defaults(@_);
+    $meta->add_attribute( $name => $args );
+}
+
+
+sub use_feature {
+    my $meta = shift;
+    my $name = shift;
+    my $args = @_ == 1 ? shift : { @_ };
+
+    $meta->features->{$name} = $args;
+}
+
+
+sub deferred_value(&) {
+    my $code = shift;
+
+    return Form::Factory::Processor::DeferredValue->new(
+        code => $code,
+    );
+}
+
+
+sub _add_function {
+    my ($type, $meta, $name, $code) = @_;
+    Carp::croak("bad code given for $type $name") unless defined $code;
+    $meta->features->{functional}{$type . '_code'}{$name} = $code;
+}
+
+sub has_cleaner        { _add_function('cleaner', @_) }
+sub has_checker        { _add_function('checker', @_) }
+sub has_pre_processor  { _add_function('pre_processor', @_) }
+sub has_post_processor { _add_function('post_processor', @_) }
+
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Processor - Moos-ish helper for action classes
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -88,28 +187,6 @@ This is the helper class used to define actions. This class automatically import
 
 Sets up the roles and meta-class information for your action class.
 
-=cut
-
-sub init_meta {
-    my $package = shift;
-    my %options = @_;
-
-    Moose->init_meta(%options);
-
-    my $meta = Moose::Util::MetaRole::apply_metaroles(
-        for             => $options{for_class},
-        class_metaroles => {
-            class => [ 'Form::Factory::Action::Meta::Class' ],
-        },
-    );
-
-    Moose::Util::apply_all_roles(
-        $options{for_class}, 'Form::Factory::Action',
-    );
-
-    return $meta;
-}
-
 =head2 has_control
 
   has_control $name => (
@@ -178,44 +255,6 @@ The C<trim> feature in the parent would remain in place as originally defined, t
 
 B<DO NOT> use the C<required> attribute option on controls. If you try to do so, the call to C<has_control> will croak because this will not work with how attributes are setup. If you need an attribute to be required, do not use a control or use the required feature instead.
 
-=cut
-
-sub _setup_control_defaults {
-    my $meta = shift;
-    my $name = shift;
-    my $args = @_ == 1 ? shift : { @_ };
-
-    # Setup default unless this is an inherited control attribute
-    unless ($name =~ /^\+/) {
-        $args->{control}  ||= 'text';
-        $args->{options}  ||= {};
-        $args->{features} ||= {};
-        $args->{traits}   ||= [];
-
-        $args->{is}       ||= 'ro';
-        $args->{isa}      ||= Form::Factory->control_class($args->{control})->default_isa;
-
-        unshift @{ $args->{traits} }, 'Form::Control';
-
-    }
-
-    Carp::croak(qq{the "required" setting is used on $name, but is forbidden on controls})
-        if $args->{required};
-
-    for my $value (values %{ $args->{features} }) {
-        $value = {} if $value and not ref $value;
-    }
-
-    $args->{__meta} = $meta;
-
-    return ($meta, $name, $args);
-}
-
-sub has_control {
-    my ($meta, $name, $args) = _setup_control_defaults(@_);
-    $meta->add_attribute( $name => $args );
-}
-
 =head2 use_feature
 
 This function is used to make an action use a particular form feature. It's usage is as follows:
@@ -230,16 +269,6 @@ will also work if you do not need to pass any features.
 
 The C<$name> is a short name for the feature class. For example, the name "require_none_or_all" will load the feature defined in L<Form::Factory::Feature::RequireNoneOrAll>.
 
-=cut
-
-sub use_feature {
-    my $meta = shift;
-    my $name = shift;
-    my $args = @_ == 1 ? shift : { @_ };
-
-    $meta->features->{$name} = $args;
-}
-
 =head2 deferred_value
 
   has_control publish_on => (
@@ -254,16 +283,6 @@ sub use_feature {
 
 This is a helper for deferring the calculation of a value. This works similar to L<Scalar::Defer> to defer the calculation, but with an important difference. The subroutine is passed the action object (such as it exists while the controls are being constructed) and the control's name. The control itself doesn't exist yet when the subroutine is called.
 
-=cut
-
-sub deferred_value(&) {
-    my $code = shift;
-
-    return Form::Factory::Processor::DeferredValue->new(
-        code => $code,
-    );
-}
-
 =head2 has_cleaner
 
   has_cleaner $name => sub { ... }
@@ -288,34 +307,19 @@ Adds some code called during the pre-process phase.
 
 Adds some code called during the post-process phase.
 
-=cut
-
-sub _add_function {
-    my ($type, $meta, $name, $code) = @_;
-    Carp::croak("bad code given for $type $name") unless defined $code;
-    $meta->features->{functional}{$type . '_code'}{$name} = $code;
-}
-
-sub has_cleaner        { _add_function('cleaner', @_) }
-sub has_checker        { _add_function('checker', @_) }
-sub has_pre_processor  { _add_function('pre_processor', @_) }
-sub has_post_processor { _add_function('post_processor', @_) }
-
 =head1 SEE ALSO
 
 L<Form::Factory::Action>
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
