@@ -1,5 +1,5 @@
 package Form::Factory::Processor::Role;
-$Form::Factory::Processor::Role::VERSION = '0.021';
+$Form::Factory::Processor::Role::VERSION = '0.022';
 use Moose;
 use Moose::Exporter;
 
@@ -15,13 +15,81 @@ Moose::Exporter->setup_import_methods(
     also      => 'Moose::Role',
 );
 
+# ABSTRACT: Moos-ish helper for action roles
+
+
+sub init_meta {
+    my $package = shift;
+    my %options = @_;
+
+    Moose::Role->init_meta(%options);
+
+    my $meta = Moose::Util::MetaRole::apply_metaroles(
+        for            => $options{for_class},
+        role_metaroles => {
+            role => [ 'Form::Factory::Action::Meta::Role' ],
+        },
+    );
+
+    Moose::Util::apply_all_roles(
+        $options{for_class}, 'Form::Factory::Action::Role',
+    );
+
+    return $meta;
+}
+
+
+sub has_control {
+    my ($meta, $name, $args) = Form::Factory::Processor::_setup_control_defaults(@_);
+    $meta->add_attribute( $name => %$args );
+}
+
+
+sub use_feature {
+    my $meta = shift;
+    my $name = shift;
+    my $args = @_ == 1 ? shift : { @_ };
+
+    $meta->features->{$name} = $args;
+}
+
+
+sub deferred_value(&) {
+    my $code = shift;
+
+    return Form::Factory::Processor::DeferredValue->new(
+        code => $code,
+    );
+}
+
+
+sub _add_function {
+    my ($type, $meta, $name, $code) = @_;
+    Carp::croak("bad code given for $type $name") unless defined $code;
+    $meta->features->{functional}{$type . '_code'}{$name} = $code;
+}
+
+sub has_cleaner        { _add_function('cleaner', @_) }
+sub has_checker        { _add_function('checker', @_) }
+sub has_pre_processor  { _add_function('pre_processor', @_) }
+sub has_post_processor { _add_function('post_processor', @_) }
+
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Processor::Role - Moos-ish helper for action roles
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -93,28 +161,6 @@ You may compose roles defined this way to build a complete action.
 
 Sets up the roles and meta-class information for your action role.
 
-=cut
-
-sub init_meta {
-    my $package = shift;
-    my %options = @_;
-
-    Moose::Role->init_meta(%options);
-
-    my $meta = Moose::Util::MetaRole::apply_metaroles(
-        for            => $options{for_class},
-        role_metaroles => {
-            role => [ 'Form::Factory::Action::Meta::Role' ],
-        },
-    );
-
-    Moose::Util::apply_all_roles(
-        $options{for_class}, 'Form::Factory::Action::Role',
-    );
-
-    return $meta;
-}
-
 =head2 has_control
 
   has_control $name => (
@@ -127,13 +173,6 @@ sub init_meta {
 
 This works very similar to L<Moose::Role/has>. This applies the L<Form::Factory::Action::Meta::Attribute::Control> trait to the attribute and sets up other defaults. These defaults match those shown in L<Form::Factory::Processor/has_control>.
 
-=cut
-
-sub has_control {
-    my ($meta, $name, $args) = Form::Factory::Processor::_setup_control_defaults(@_);
-    $meta->add_attribute( $name => %$args );
-}
-
 =head2 use_feature
 
 This function is used to make an action role use a particular form feature. You use it like this:
@@ -146,16 +185,6 @@ The C<%options> are optional. So, this is also acceptable:
 
 The C<$name> is a short name for the feature class. For example, the name "require_none_or_all" will load teh feature defined in L<Form::Factory::Features::RequireNoneOrAll>.
 
-=cut
-
-sub use_feature {
-    my $meta = shift;
-    my $name = shift;
-    my $args = @_ == 1 ? shift : { @_ };
-
-    $meta->features->{$name} = $args;
-}
-
 =head2 deferred_value
 
   has_control publish_on => (
@@ -170,16 +199,6 @@ sub use_feature {
 
 This is a helper for deferring the calculation of a value. This works similar to L<Scalar::Defer> to defer the calculation, but with an important difference. The subroutine is passed the action object (such as it exists while the controls are being constructed) and the control's name. The control itself doesn't exist yet when the subroutine is called.
 
-=cut
-
-sub deferred_value(&) {
-    my $code = shift;
-
-    return Form::Factory::Processor::DeferredValue->new(
-        code => $code,
-    );
-}
-
 =head2 has_cleaner
 
   has_cleaner $name => sub { ... }
@@ -204,34 +223,19 @@ Adds some code called during the pre-process phase.
 
 Adds some code called during the post-process phase.
 
-=cut
-
-sub _add_function {
-    my ($type, $meta, $name, $code) = @_;
-    Carp::croak("bad code given for $type $name") unless defined $code;
-    $meta->features->{functional}{$type . '_code'}{$name} = $code;
-}
-
-sub has_cleaner        { _add_function('cleaner', @_) }
-sub has_checker        { _add_function('checker', @_) }
-sub has_pre_processor  { _add_function('pre_processor', @_) }
-sub has_post_processor { _add_function('post_processor', @_) }
-
 =head1 SEE ALSO
 
 L<Form::Factory::Action::Role>
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2010 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
