@@ -1,16 +1,125 @@
 package Form::Factory::Result;
-$Form::Factory::Result::VERSION = '0.021';
+$Form::Factory::Result::VERSION = '0.022';
 use Moose::Role;
 
 use Form::Factory::Message;
 
+# ABSTRACT: Interface for the result classes
+
+
+# requires qw(
+#     is_valid is_validated
+#     is_success is_outcome_known
+#     content
+#     messages
+# );
+
+sub is_failure {
+    my $self = shift;
+    return not $self->is_success;
+}
+
+
+sub _return(&@) {
+    my ($filter, @messages) = @_;
+    
+    my @filtered = grep { $filter->() } @messages;
+    return wantarray ? @filtered : join "\n", map { $_->message } @filtered;
+}
+
+sub all_messages {
+    my $self = shift;
+    return _return { 1 } @{ $self->messages };
+}
+
+
+sub info_messages {
+    my $self = shift;
+    return _return { $_->type eq 'info' } @{ $self->messages };
+}
+
+
+sub warning_messages {
+    my $self = shift;
+    return _return { $_->type eq 'warning' } @{ $self->messages };
+}
+
+
+sub error_messages {
+    my $self = shift;
+    return _return { $_->type eq 'error' } @{ $self->messages };
+}
+
+
+sub regular_messages {
+    my $self = shift;
+    return _return { not $_->is_tied_to_field } @{ $self->messages };
+}
+
+
+sub regular_info_messages {
+    my $self = shift;
+    return _return { not $_->is_tied_to_field and $_->type eq 'info' } 
+               @{ $self->messages };
+}
+
+
+sub regular_warning_messages {
+    my $self = shift;
+    return _return { not $_->is_tied_to_field and $_->type eq 'warning' }
+               @{ $self->messages };
+}
+
+
+sub regular_error_messages {
+    my $self = shift;
+    return _return { not $_->is_tied_to_field and $_->type eq 'error' } 
+               @{ $self->messages };
+}
+
+
+sub field_messages {
+    my ($self, $field) = @_;
+    return _return { $_->is_tied_to_field and $_->field eq $field } 
+               @{ $self->messages };
+}
+
+
+sub field_info_messages {
+    my ($self, $field) = @_;
+    return _return { $_->is_tied_to_field and $_->field eq $field and $_->type eq 'info'} 
+               @{ $self->messages };
+}
+
+
+sub field_warning_messages {
+    my ($self, $field) = @_;
+    return _return { $_->is_tied_to_field and $_->field eq $field and $_->type eq 'warning'} 
+               @{ $self->messages };
+}
+
+
+sub field_error_messages {
+    my ($self, $field) = @_;
+    return _return { $_->is_tied_to_field and $_->field eq $field and $_->type eq 'error'} 
+               @{ $self->messages };
+}
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Result - Interface for the result classes
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -38,20 +147,6 @@ After an action has run in part or in whole, a result class will contain the cur
 
 The opposite of L</is_success>.
 
-=cut
-
-# requires qw(
-#     is_valid is_validated
-#     is_success is_outcome_known
-#     content
-#     messages
-# );
-
-sub is_failure {
-    my $self = shift;
-    return not $self->is_success;
-}
-
 =head2 all_messages
 
   my $messages = $result->all_messages;
@@ -59,20 +154,6 @@ sub is_failure {
 
 Returns all messages. When a scalar is expected, it returns all messages concatenated with a newline between each. When a list is expected, it returns a list of L<Form::Factory::Message> objects.
 
-=cut
-
-sub _return(&@) {
-    my ($filter, @messages) = @_;
-    
-    my @filtered = grep { $filter->() } @messages;
-    return wantarray ? @filtered : join "\n", map { $_->message } @filtered;
-}
-
-sub all_messages {
-    my $self = shift;
-    return _return { 1 } @{ $self->messages };
-}
-
 =head2 info_messages
 
   my $messages = $result->info_messages;
@@ -80,13 +161,6 @@ sub all_messages {
 
 Returns all mesages with type info. Handles context the same as L</all_messages>.
 
-=cut
-
-sub info_messages {
-    my $self = shift;
-    return _return { $_->type eq 'info' } @{ $self->messages };
-}
-
 =head2 warning_messages
 
   my $messages = $result->warning_messages;
@@ -94,13 +168,6 @@ sub info_messages {
 
 Returns all messages with type warning. Handles context the same as L</all_messages>.
 
-=cut
-
-sub warning_messages {
-    my $self = shift;
-    return _return { $_->type eq 'warning' } @{ $self->messages };
-}
-
 =head2 error_messages
 
   my $messages = $result->error_messages;
@@ -108,13 +175,6 @@ sub warning_messages {
 
 Returns all messages with type error. Handles context the same as L</all_messages>.
 
-=cut
-
-sub error_messages {
-    my $self = shift;
-    return _return { $_->type eq 'error' } @{ $self->messages };
-}
-
 =head2 regular_messages
 
   my $messages = $result->regular_messages;
@@ -122,13 +182,6 @@ sub error_messages {
 
 Returns all messages that are not tied to a field. Handles context the same as L</all_messages>.
 
-=cut
-
-sub regular_messages {
-    my $self = shift;
-    return _return { not $_->is_tied_to_field } @{ $self->messages };
-}
-
 =head2 regular_info_messages
 
   my $messages = $result->regular_info_messages;
@@ -136,14 +189,6 @@ sub regular_messages {
 
 Returns all messages with type info that are not tied to a field. Handles context the same as L</all_messages>.
 
-=cut
-
-sub regular_info_messages {
-    my $self = shift;
-    return _return { not $_->is_tied_to_field and $_->type eq 'info' } 
-               @{ $self->messages };
-}
-
 =head2 regular_warning_messages
 
   my $messages = $result->regular_warning_messages;
@@ -151,14 +196,6 @@ sub regular_info_messages {
 
 Returns all messages with type warning that are not tied to a feild. Handles context the same as L</all_messages>.
 
-=cut
-
-sub regular_warning_messages {
-    my $self = shift;
-    return _return { not $_->is_tied_to_field and $_->type eq 'warning' }
-               @{ $self->messages };
-}
-
 =head2 regular_error_messages
 
   my $messages = $result->regular_error_messages;
@@ -166,14 +203,6 @@ sub regular_warning_messages {
 
 Returns all messages with type error that are not tied to a field. Handles context the same as L</all_messages>.
 
-=cut
-
-sub regular_error_messages {
-    my $self = shift;
-    return _return { not $_->is_tied_to_field and $_->type eq 'error' } 
-               @{ $self->messages };
-}
-
 =head2 field_messages
 
   my $messages = $result->field_messages($field);
@@ -181,14 +210,6 @@ sub regular_error_messages {
 
 Returns all messages that are tied to a particular field. Handles context the same as L</all_messages>.
 
-=cut
-
-sub field_messages {
-    my ($self, $field) = @_;
-    return _return { $_->is_tied_to_field and $_->field eq $field } 
-               @{ $self->messages };
-}
-
 =head2 field_info_messages
 
   my $messages = $result->field_info_messages($field);
@@ -196,14 +217,6 @@ sub field_messages {
 
 Returns all messages with type info that are tied to a particular field. Handles context the same as L</all_messages>.
 
-=cut
-
-sub field_info_messages {
-    my ($self, $field) = @_;
-    return _return { $_->is_tied_to_field and $_->field eq $field and $_->type eq 'info'} 
-               @{ $self->messages };
-}
-
 =head2 field_warning_messages
 
   my $messages = $result->field_warning_messages($field);
@@ -211,14 +224,6 @@ sub field_info_messages {
 
 Returns all messages with type warning tied to a particular field. Handles context the same as L</all_messages>.
 
-=cut
-
-sub field_warning_messages {
-    my ($self, $field) = @_;
-    return _return { $_->is_tied_to_field and $_->field eq $field and $_->type eq 'warning'} 
-               @{ $self->messages };
-}
-
 =head2 field_error_messages
 
   my $messages = $result->field_error_messages($field);
@@ -226,25 +231,15 @@ sub field_warning_messages {
 
 Returns all messages with type error tied to a particular field. Handles context the same as L</all_messages>.
 
-=cut
-
-sub field_error_messages {
-    my ($self, $field) = @_;
-    return _return { $_->is_tied_to_field and $_->field eq $field and $_->type eq 'error'} 
-               @{ $self->messages };
-}
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
