@@ -1,16 +1,27 @@
 package Form::Factory::Stasher;
-$Form::Factory::Stasher::VERSION = '0.021';
+$Form::Factory::Stasher::VERSION = '0.022';
 use Moose::Role;
 
 requires qw( stash unstash );
 
+# ABSTRACT: An object responsible for remembering things
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Stasher - An object responsible for remembering things
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 DESCRIPTION
 
@@ -36,15 +47,13 @@ L<Form::Factory::Stasher::Memory>
 
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
