@@ -1,16 +1,46 @@
 package Form::Factory::Stasher::Memory;
-$Form::Factory::Stasher::Memory::VERSION = '0.021';
+$Form::Factory::Stasher::Memory::VERSION = '0.022';
 use Moose;
 
 with qw( Form::Factory::Stasher );
 
+# ABSTRACT: Remember things in a Perl hash
+
+
+has stash_hash => (
+    is        => 'rw',
+    isa       => 'HashRef',
+    required  => 1,
+    default   => sub { {} },
+);
+
+
+sub stash {
+    my ($self, $moniker, $stash) = @_;
+    $self->stash_hash->{ $moniker } = $stash;
+}
+
+
+sub unstash {
+    my ($self, $moniker) = @_;
+    delete $self->stash_hash->{ $moniker };
+}
+
+__PACKAGE__->meta->make_immutable;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Form::Factory::Stasher::Memory - Remember things in a Perl hash
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -32,50 +62,25 @@ Stashes things into a plain memory hash. This is useful if you already have a me
 
 The hash reference to stash stuff into. Defaults to an empty anonymous hash.
 
-=cut
-
-has stash_hash => (
-    is        => 'rw',
-    isa       => 'HashRef',
-    required  => 1,
-    default   => sub { {} },
-);
-
 =head1 METHODS
 
 =head2 stash
 
 Stash the stuff given.
 
-=cut
-
-sub stash {
-    my ($self, $moniker, $stash) = @_;
-    $self->stash_hash->{ $moniker } = $stash;
-}
-
 =head2 unstash
 
 Unstash the stuff requested.
 
-=cut
-
-sub unstash {
-    my ($self, $moniker) = @_;
-    delete $self->stash_hash->{ $moniker };
-}
-
 =head1 AUTHOR
 
-Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
+Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Qubling Software LLC.
+This software is copyright (c) 2015 by Qubling Software LLC.
 
-This library is free software. You can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
